import { Response } from "node-fetch";
export interface MonitorParams {
    [key: string]: any;
}
export interface Monitor {
    [key: string]: MonitorParams;
}
export interface ServerlessMonitor {
    name: string;
    threshold: number;
    query: (cloudFormationStackId: string, criticalThreshold: number) => string;
    message: string;
    type?: string;
}
export interface RecommendedMonitors {
    [key: string]: ServerlessMonitor;
}
/**
 * Adds the appropriate tags and required parameters that will be passed as part of the request body for creating and updating monitors
 * @param monitor - the Monitor object that is defined in the serverless.yml file
 * @param cloudFormationStackId - the Cloud Formation Stack ID
 * @param service - the Service
 * @param env  - the Environment
 * @returns valid monitor parameters
 */
export declare function buildMonitorParams(monitor: Monitor, cloudFormationStackId: string, service: string, env: string, recommendedMonitors: RecommendedMonitors): {
    [x: string]: any;
};
/**
 * Handles the Monitor API response and logs the appropriate error
 * @param response Monitor API Response
 * @param serverlessMonitorId Serverless Monitor ID
 * @param subdomain
 * @param site
 */
export declare function handleMonitorsApiResponse(response: Response, serverlessMonitorId?: string, subdomain?: string, site?: string): boolean;
/**
 * Creates, updates, and deletes the appropriate monitor configurations as defined in the serverless.yml file
 * @param monitors - Monitors defined in the serverless.yml file
 * @param monitorsApiKey - the API Key
 * @param monitorsAppKey - the Application Key
 * @param cloudFormationStackId - the Cloud Formation Stack ID
 * @param service - the Service
 * @param env - the Environment
 * @returns monitors that have been successfully created, updated, and deleted according to the configuration defined in the plugin
 */
export declare function setMonitors(subdomain: string, site: string, monitors: Monitor[], monitorsApiKey: string, monitorsAppKey: string, cloudFormationStackId: string, service: string, env: string): Promise<string[]>;
/** Helper function that replaces the default threshold included in the query string with the new critical threshold configured by the customer
 * @param query - the query string
 * @param criticalThreshold = new critical threshold as defined by the customer
 */
export declare function replaceCriticalThreshold(query: string, criticalThreshold: number): string;
//# sourceMappingURL=monitors.d.ts.map